@@ -18,6 +18,7 @@ DEFAULT_IMAGE_DISTRO = "debian"
 
 
 Distros = Literal["debian", "wolfi", "bullseye", "bookworm"]
+MiddlewareOrders = Literal["auth_first", "middleware_first"]
 
 
 class TTLConfig(TypedDict, total=False):
@@ -359,6 +360,25 @@ class HttpConfig(TypedDict, total=False):
     agent's behavior or permissions on a request's headers."""
     logging_headers: Optional[ConfigurableHeaderConfig]
     """Optional. Defines which headers are excluded from logging."""
+    middleware_order: Optional[MiddlewareOrders]
+    """Optional. Defines the order in which to apply server customizations.
+
+    Choices:
+      - "auth_first": Authentication hooks (custom or default) are evaluated
+      before custom middleware.
+      - "middleware_first": Custom middleware is evaluated
+      before authentication hooks (custom or default).
+
+    Default is `middleware_first`.
+    """
+    enable_custom_route_auth: bool
+    """Optional. If True, authentication is enabled for custom routes,
+    not just the routes that are protected by default.
+    (Routes protected by default include /assistants, /threads, and /runs).
+
+    Default is False. This flag only affects authentication behavior
+    if `app` is provided and contains custom routes.
+    """
 
 
 class Config(TypedDict, total=False):
@@ -1263,9 +1283,15 @@ def python_config_to_docker(
         raise ValueError(f"Invalid pip_installer: {pip_installer}")
 
     # configure pip
-    pip_install = f"PYTHONDONTWRITEBYTECODE=1 {install_cmd} --no-cache-dir -c /api/constraints.txt"
+    local_reqs_pip_install = f"PYTHONDONTWRITEBYTECODE=1 {install_cmd} --no-cache-dir -c /api/constraints.txt"
+    global_reqs_pip_install = f"PYTHONDONTWRITEBYTECODE=1 {install_cmd} --no-cache-dir -c /api/constraints.txt"
     if config.get("pip_config_file"):
-        pip_install = f"PIP_CONFIG_FILE=/pipconfig.txt {pip_install}"
+        local_reqs_pip_install = (
+            f"PIP_CONFIG_FILE=/pipconfig.txt {local_reqs_pip_install}"
+        )
+        global_reqs_pip_install = (
+            f"PIP_CONFIG_FILE=/pipconfig.txt {global_reqs_pip_install}"
+        )
     pip_config_file_str = (
         f"ADD {config['pip_config_file']} /pipconfig.txt"
         if config.get("pip_config_file")
@@ -1282,7 +1308,9 @@ def python_config_to_docker(
     # Rewrite HTTP app path, so it points to the correct location in the Docker container
     _update_http_app_path(config_path, config, local_deps)
 
-    pip_pkgs_str = f"RUN {pip_install} {' '.join(pypi_deps)}" if pypi_deps else ""
+    pip_pkgs_str = (
+        f"RUN {local_reqs_pip_install} {' '.join(pypi_deps)}" if pypi_deps else ""
+    )
     if local_deps.pip_reqs:
         pip_reqs_str = os.linesep.join(
             (
@@ -1292,7 +1320,7 @@ def python_config_to_docker(
             )
             for reqpath, destpath in local_deps.pip_reqs
         )
-        pip_reqs_str += f"{os.linesep}RUN {pip_install} {' '.join('-r ' + r for _, r in local_deps.pip_reqs)}"
+        pip_reqs_str += f"{os.linesep}RUN {local_reqs_pip_install} {' '.join('-r ' + r for _, r in local_deps.pip_reqs)}"
         pip_reqs_str = f"""# -- Installing local requirements --
 {pip_reqs_str}
 # -- End of local requirements install --"""
@@ -1402,7 +1430,13 @@ ADD {relpath} /deps/{name}
         installs,
         "",
         "# -- Installing all local dependencies --",
-        f"RUN {pip_install} -e /deps/*",
+        f"""RUN for dep in /deps/*; do \
+            echo "Installing $dep"; \
+            if [ -d "$dep" ]; then \
+                echo "Installing $dep"; \
+                (cd "$dep" && {global_reqs_pip_install} .); \
+            fi; \
+        done""",
         "# -- End of local dependencies install --",
         os.linesep.join(env_vars),
         "",
